@@ -1,12 +1,12 @@
 from dagster.core.utils import check_dagster_package_version
 
 from .context import DagstermillExecutionContext
-from .errors import DagstermillError, DagstermillExecutionError
+from .errors import DagstermillError
 from .manager import MANAGER_FOR_NOTEBOOK_INSTANCE as _MANAGER_FOR_NOTEBOOK_INSTANCE
 from .solids import define_dagstermill_solid
 from .version import __version__
 
-check_dagster_package_version('dagstermill', __version__)
+check_dagster_package_version("dagstermill", __version__)
 
 get_context = _MANAGER_FOR_NOTEBOOK_INSTANCE.get_context
 
@@ -19,3 +19,5 @@ _reconstitute_pipeline_context = _MANAGER_FOR_NOTEBOOK_INSTANCE.reconstitute_pip
 _teardown = _MANAGER_FOR_NOTEBOOK_INSTANCE.teardown_resources
 
 _load_parameter = _MANAGER_FOR_NOTEBOOK_INSTANCE.load_parameter
+
+_load_input_parameter = _MANAGER_FOR_NOTEBOOK_INSTANCE.load_input_parameter
